
# Exampville Simulator

Exampville is a simulation tool provided with Larch that can quickly simulate the
kind of data that a transportation planner might have available when building
a travel model.  The choice specifications are not particularly rich, but the
size of the data is small enough to run quickly but large enough to be useful,
and the technical implementation is generally realistic.

```{toctree}
:glob:

2*
```
